package AlphabetRole;

use Minions::Role;

sub alpha   { 'alpha' }
sub bravo   { 'bravo' }
sub charlie { 'charlie' }
sub delta   { 'delta' }

1;
